Petri
===========

Master
----------------
.. automodule:: pykaryote.petri.master

.. autoclass:: pykaryote.petri.master.Master
	:members:

Worker
--------
.. automodule:: pykaryote.petri.worker

.. autoclass:: pykaryote.petri.worker.Worker
	:members:

Tags
---------
.. automodule:: pykaryote.petri.tags
	:members:
